<?php

/**
 * Security functions
 */
class Security {

    /** @var int Run as a single user requiring no password */
    public const int SINGLE_USER = 0;

    /** @var int Run as a single user requiring a password */
    public const int SINGLE_USER_WITH_PASSWORD = 1;

    /** @var int Require users to provide e-mail address and password */
    public const int MULTI_USER = 2;

    /**
     * Verify that user is logged on
     * @param bool $redirectIfAnonymous Whether to redirect the request if there is no user logged on
     */
    public static function verifyUser(bool $redirectIfAnonymous = true): void {
        switch (SECURITY_MODEL) {
            case self::SINGLE_USER:
                $user = self::retrieveSingleUser();
                break;
            case self::SINGLE_USER_WITH_PASSWORD:
                die('Single User w/ Password has not yet been implemented');
            case self::MULTI_USER:
                die('Multi-User Mode has not yet been implemented');
            default:
                die('Unrecognized security model (' . SECURITY_MODEL . ')');
        }
        if (!$user && $redirectIfAnonymous) {
            header('/logon?returnTo=' . $_SERVER['REQUEST_URI'], true, HTTP_REDIRECT_TEMP);
            die();
        }
        $_REQUEST[Key::USER_ID]    = $user['id'];
        $_REQUEST[Key::USER_EMAIL] = $user['email'];
    }

    /**
     * Retrieve the single user
     * @return array The user information for the single user
     */
    private static function retrieveSingleUser(): array {
        $user = Data::findUserByEmail('solouser@example.com');
        if ($user) return $user;
        Data::addUser('solouser@example.com', 'no-password-required');
        return Data::findUserByEmail('solouser@example.com');
    }
}
